@@ -25,15 +25,13 @@ public:
 	~datenclass();
 
 	QStrList services_list;
-	QStrList print_list;
-//	QStrList protocol_list;
+	QStrList delete_list;
 
 	void getGlobalData();
 	void getServiceData();
 	void saveSmbconfFile();
-	void newService(QString servicename, int servicetype, QString servicepath);
+	void newService(QString servicename, QString servicetype, QString servicepath);
 	void deleteService(int index);
-//	void changeAvailable(int index, bool value);
 	QCharDict *getGlobalDataPointer();
 	QCharDict *getGlobalDefaultsPointer();
 	QCharDict *getServiceDataPointer(int index);
@@ -52,7 +50,7 @@ private:
 
 	KSimpleConfig	*confdata;
 	QTextStream	*tmp_line;
-	QString		tmp_string;
+	QString		*tmpstring;
 	QString		tmp2_string;
 	QCharDict	*globaldaten;
 	QCharDict	*globaldefaults;
