@@ -46,7 +46,7 @@ const char *myglobalwidget::getWorkgroup()
 
 void myglobalwidget::saveData(QCharDict *GlobalDaten)
 {
-//	KDEBUG(KDEBUG_INFO,3700-3800,"start saving data");
+	KDEBUG(KDEBUG_INFO,3700-3800,"start saving data");
 	if (strcmp(GlobalWidget_Page2->autoservices_lineed->text(),
 		   GlobalDaten->find("auto services")) != 0)
 	{
@@ -226,7 +226,7 @@ void myglobalwidget::saveData(QCharDict *GlobalDaten)
 	else
 	GlobalDaten->replace("load printers","no");
 
-	if (GlobalWidget_Page1->local_master_chkbx->isChecked())
+	if (GlobalWidget_Page3->local_master_chkbx->isChecked())
 	GlobalDaten->replace("local master","yes");
 	else
 	GlobalDaten->replace("local master","no");
@@ -311,6 +311,13 @@ void myglobalwidget::saveData(QCharDict *GlobalDaten)
 		GlobalDaten->replace("message command",retData->data());
 	}
 
+	if (strcmp(GlobalWidget_Page4->name_resolve_order_lineed->text(),
+		   GlobalDaten->find("name resolve order")) != 0)
+	{
+		retData = new QString(GlobalWidget_Page4->name_resolve_order_lineed->text());
+		GlobalDaten->replace("name resolve order",retData->data());
+	}
+
 	if (strcmp(GlobalWidget_Page4->netbios_aliases_lineed->text(),
 		   GlobalDaten->find("netbios aliases")) != 0)
 	{
@@ -325,6 +332,11 @@ void myglobalwidget::saveData(QCharDict *GlobalDaten)
 		GlobalDaten->replace("netbios name",retData->data());
 	}
 
+	if (GlobalWidget_Page3->networkstation_user_login_chkbx->isChecked())
+	GlobalDaten->replace("networkstation user login","yes");
+	else
+	GlobalDaten->replace("networkstation user login","no");
+
 	if (GlobalWidget_Page3->nis_homedir_chkbx->isChecked())
 	GlobalDaten->replace("nis homedir","yes");
 	else
@@ -484,6 +496,11 @@ void myglobalwidget::saveData(QCharDict *GlobalDaten)
 	else
 	GlobalDaten->replace("time server","no");
 
+	if (GlobalWidget_Page1->unix_password_sync_chkbx->isChecked())
+	GlobalDaten->replace("unix password sync","yes");
+	else
+	GlobalDaten->replace("unix password sync","no");
+
 	if (GlobalWidget_Page1->unix_realname_chkbx->isChecked())
 	GlobalDaten->replace("unix realname","yes");
 	else
@@ -661,9 +678,9 @@ void myglobalwidget::setData(QCharDict *GlobalDaten)
 	GlobalWidget_Page1->load_printers_chkbx->setChecked(FALSE);
 
 	if (strcmp(GlobalDaten->find("local master"),"yes") == 0)
-	GlobalWidget_Page1->local_master_chkbx->setChecked(TRUE);
+	GlobalWidget_Page3->local_master_chkbx->setChecked(TRUE);
 	else
-	GlobalWidget_Page1->local_master_chkbx->setChecked(FALSE);
+	GlobalWidget_Page3->local_master_chkbx->setChecked(FALSE);
 
 	GlobalWidget_Page1->lock_dir_lineed->setText(GlobalDaten->find("lock directory"));
 
@@ -687,10 +704,17 @@ void myglobalwidget::setData(QCharDict *GlobalDaten)
 
 	GlobalWidget_Page2->message_cmd_lineed->setText(GlobalDaten->find("message command"));
 
+	GlobalWidget_Page4->name_resolve_order_lineed->setText(GlobalDaten->find("name resolve order"));
+
 	GlobalWidget_Page4->netbios_aliases_lineed->setText(GlobalDaten->find("netbios aliases"));
 
 	GlobalWidget_Page4->netbios_name_lineed->setText(GlobalDaten->find("netbios name"));
 
+	if (strcmp(GlobalDaten->find("networkstation user login"),"yes") == 0)
+	GlobalWidget_Page3->networkstation_user_login_chkbx->setChecked(TRUE);
+	else
+	GlobalWidget_Page3->networkstation_user_login_chkbx->setChecked(FALSE);
+
 	if (strcmp(GlobalDaten->find("nis homedir"),"yes") == 0)
 	GlobalWidget_Page3->nis_homedir_chkbx->setChecked(TRUE);
 	else
@@ -788,6 +812,11 @@ void myglobalwidget::setData(QCharDict *GlobalDaten)
 	else
 	GlobalWidget_Page1->time_server_chkbx->setChecked(FALSE);
 
+	if (strcmp(GlobalDaten->find("unix password sync"),"yes") == 0)
+	GlobalWidget_Page1->unix_password_sync_chkbx->setChecked(TRUE);
+	else
+	GlobalWidget_Page1->unix_password_sync_chkbx->setChecked(FALSE);
+
 	if (strcmp(GlobalDaten->find("unix realname"),"yes") == 0)
 	GlobalWidget_Page1->unix_realname_chkbx->setChecked(TRUE);
 	else
