@@ -20,13 +20,16 @@ myprinterwidget::myprinterwidget(QWidget* parent,const char* name, bool modal)
 {
 	ServiceWidget_Page1 = new myservicewidget_page1(this);
 	ServiceWidget_Page2 = new myservicewidget_page2(this);
+	ServiceWidget_Page3 = new myservicewidget_page3(this);
+	ServiceWidget_Page4 = new myservicewidget_page4(this);
 	PrinterWidget_Page1 = new myprinterwidget_page1(this);
-//	GlobalWidget_Page4 = new myglobalwidget_page4(this);
 
-	addTab(ServiceWidget_Page1,"Page 1");
-	addTab(ServiceWidget_Page2,"Page 2");
-	addTab(PrinterWidget_Page1,"Page 3");
-//	addTab(GlobalWidget_Page4,"Page 4");
+
+	addTab(ServiceWidget_Page1,"Main");
+	addTab(ServiceWidget_Page2,"Misc");
+	addTab(ServiceWidget_Page3,"Name Mangling");
+	addTab(ServiceWidget_Page4,"File/Dir Mask");
+	addTab(PrinterWidget_Page1,"Printersettings");
 
 	setCaption( "Printer Settings" );
 	setCancelButton("Cancel");
@@ -38,6 +41,9 @@ myprinterwidget::myprinterwidget(QWidget* parent,const char* name, bool modal)
 
 void myprinterwidget::saveData(QCharDict *ServiceDaten)
 {
+	QString tmpstring;
+	int mode;
+
 //	printf("service name = %s\n", ServiceDaten->find("service name"));
 
 	if (strcmp(ServiceWidget_Page1->admin_users_lineed->text(),
@@ -64,6 +70,11 @@ void myprinterwidget::saveData(QCharDict *ServiceDaten)
 	else
 	ServiceDaten->replace("browseable","no");
 
+	if (ServiceWidget_Page3->case_sensitive_chkbx->isChecked())
+	ServiceDaten->replace("case sensitive","yes");
+	else
+	ServiceDaten->replace("case sensitive","no");
+
 	if (strcmp(ServiceWidget_Page1->comment_lineed->text(),
 		   ServiceDaten->find("comment")) != 0)
 	{
@@ -71,10 +82,10 @@ void myprinterwidget::saveData(QCharDict *ServiceDaten)
 		ServiceDaten->replace("comment",retData->data());
 	}
 
-	if (strcmp(ServiceWidget_Page2->default_case_combo->currentText(),
+	if (strcmp(ServiceWidget_Page3->default_case_combo->currentText(),
 		   ServiceDaten->find("default case")) != 0)
 	{
-		retData = new QString(ServiceWidget_Page2->default_case_combo->currentText());
+		retData = new QString(ServiceWidget_Page3->default_case_combo->currentText());
 		ServiceDaten->replace("default case",retData->data());
 	}
 
@@ -100,11 +111,28 @@ void myprinterwidget::saveData(QCharDict *ServiceDaten)
 		ServiceDaten->replace("deny hosts",retData->data());
 	}
 
+	if (strcmp(ServiceWidget_Page3->dont_descend_lineed->text(),
+		   ServiceDaten->find("dont descend")) != 0)
+	{
+		retData = new QString(ServiceWidget_Page3->dont_descend_lineed->text());
+		ServiceDaten->replace("dont descend",retData->data());
+	}
+
+	if (ServiceWidget_Page2->dos_filetime_resolution_chkbx->isChecked())
+	ServiceDaten->replace("dos filetime resolution","yes");
+	else
+	ServiceDaten->replace("dos filetime resolution","no");
+
 	if (ServiceWidget_Page2->dos_filetimes_chkbx->isChecked())
 	ServiceDaten->replace("dos filetimes","yes");
 	else
 	ServiceDaten->replace("dos filetimes","no");
 
+	if (ServiceWidget_Page2->fake_directory_create_times_chkbx->isChecked())
+	ServiceDaten->replace("fake directory create times","yes");
+	else
+	ServiceDaten->replace("fake directory create times","no");
+
 	if (ServiceWidget_Page2->fake_oplocks_chkbx->isChecked())
 	ServiceDaten->replace("fake oplocks","yes");
 	else
@@ -127,11 +155,18 @@ void myprinterwidget::saveData(QCharDict *ServiceDaten)
 	else
 	ServiceDaten->replace("guest only","no");
 
-	if (ServiceWidget_Page2->hide_dot_files_chkbx->isChecked())
+	if (ServiceWidget_Page1->hide_dot_files_chkbx->isChecked())
 	ServiceDaten->replace("hide dot files","yes");
 	else
 	ServiceDaten->replace("hide dot files","no");
 
+	if (strcmp(ServiceWidget_Page3->hide_files_lineed->text(),
+		   ServiceDaten->find("hide files")) != 0)
+	{
+		retData = new QString(ServiceWidget_Page3->hide_files_lineed->text());
+		ServiceDaten->replace("hide files",retData->data());
+	}
+
 	if (strcmp(ServiceWidget_Page1->invalid_users_lineed->text(),
 		   ServiceDaten->find("invalid users")) != 0)
 	{
@@ -172,11 +207,30 @@ void myprinterwidget::saveData(QCharDict *ServiceDaten)
 		ServiceDaten->replace("lpq command",retData->data());
 	}
 
-	if (ServiceWidget_Page2->mangled_names_chkbx->isChecked())
+	if (ServiceWidget_Page3->mangle_case_chkbx->isChecked())
+	ServiceDaten->replace("mangle case","yes");
+	else
+	ServiceDaten->replace("mangle case","no");
+
+	if (strcmp(ServiceWidget_Page3->mangled_map_lineed->text(),
+		   ServiceDaten->find("mangled map")) != 0)
+	{
+		retData = new QString(ServiceWidget_Page3->mangled_map_lineed->text());
+		ServiceDaten->replace("mangled map",retData->data());
+	}
+
+	if (ServiceWidget_Page3->mangled_names_chkbx->isChecked())
 	ServiceDaten->replace("mangled names","yes");
 	else
 	ServiceDaten->replace("mangled names","no");
 
+	if (strcmp(ServiceWidget_Page3->mangling_char_lineed->text(),
+		   ServiceDaten->find("mangling char")) != 0)
+	{
+		retData = new QString(ServiceWidget_Page3->mangling_char_lineed->text());
+		ServiceDaten->replace("mangling char",retData->data());
+	}
+
 	if (ServiceWidget_Page2->map_archive_chkbx->isChecked())
 	ServiceDaten->replace("map archive","yes");
 	else
@@ -223,7 +277,7 @@ void myprinterwidget::saveData(QCharDict *ServiceDaten)
 	else
 	ServiceDaten->replace("postscript","no");
 
-	if (ServiceWidget_Page2->preserve_case_chkbx->isChecked())
+	if (ServiceWidget_Page3->preserve_case_chkbx->isChecked())
 	ServiceDaten->replace("preserve case","yes");
 	else
 	ServiceDaten->replace("preserve case","no");
@@ -290,7 +344,7 @@ void myprinterwidget::saveData(QCharDict *ServiceDaten)
 	else
 	ServiceDaten->replace("share modes","no");
 
-	if (ServiceWidget_Page2->short_preserve_case_chkbx->isChecked())
+	if (ServiceWidget_Page3->short_preserve_case_chkbx->isChecked())
 	ServiceDaten->replace("short preserve case","yes");
 	else
 	ServiceDaten->replace("short preserve case","no");
@@ -342,7 +396,93 @@ void myprinterwidget::saveData(QCharDict *ServiceDaten)
 		retData = new QString(ServiceWidget_Page1->write_list_lineed->text());
 		ServiceDaten->replace("write list",retData->data());
 	}
-	KDEBUG(KDEBUG_INFO,3801,"myservicewidget: exit ok/data saved");
+
+//	ServiceWidget_Page4
+
+	//save create mode
+	mode=0;
+	if (ServiceWidget_Page4->cm_oe_chkbx->isChecked()) mode=mode+1;
+	if (ServiceWidget_Page4->cm_ow_chkbx->isChecked()) mode=mode+2;
+	if (ServiceWidget_Page4->cm_or_chkbx->isChecked()) mode=mode+4;
+	if (ServiceWidget_Page4->cm_ge_chkbx->isChecked()) mode=mode+10;
+	if (ServiceWidget_Page4->cm_gw_chkbx->isChecked()) mode=mode+20;
+	if (ServiceWidget_Page4->cm_gr_chkbx->isChecked()) mode=mode+40;
+	if (ServiceWidget_Page4->cm_ue_chkbx->isChecked()) mode=mode+100;
+	if (ServiceWidget_Page4->cm_uw_chkbx->isChecked()) mode=mode+200;
+	if (ServiceWidget_Page4->cm_ur_chkbx->isChecked()) mode=mode+400;
+	tmpstring=tmpstring.setNum(mode);
+	tmpstring=tmpstring.rightJustify(4,'0');
+	if (strcmp(tmpstring.data(), ServiceDaten->find("create mask")) != 0)
+	{
+		retData = new QString(tmpstring.data());
+		ServiceDaten->replace("create mask",retData->data());
+//		printf("new create mask= %s\n", tmpstring.data());
+	}
+
+	//save directory mode
+	mode=0;
+	if (ServiceWidget_Page4->dm_oe_chkbx->isChecked()) mode=mode+1;
+	if (ServiceWidget_Page4->dm_ow_chkbx->isChecked()) mode=mode+2;
+	if (ServiceWidget_Page4->dm_or_chkbx->isChecked()) mode=mode+4;
+	if (ServiceWidget_Page4->dm_ge_chkbx->isChecked()) mode=mode+10;
+	if (ServiceWidget_Page4->dm_gw_chkbx->isChecked()) mode=mode+20;
+	if (ServiceWidget_Page4->dm_gr_chkbx->isChecked()) mode=mode+40;
+	if (ServiceWidget_Page4->dm_ue_chkbx->isChecked()) mode=mode+100;
+	if (ServiceWidget_Page4->dm_uw_chkbx->isChecked()) mode=mode+200;
+	if (ServiceWidget_Page4->dm_ur_chkbx->isChecked()) mode=mode+400;
+	tmpstring=tmpstring.setNum(mode);
+	tmpstring=tmpstring.rightJustify(4,'0');
+	if (strcmp(tmpstring.data(), ServiceDaten->find("directory mask")) != 0)
+	{
+		retData = new QString(tmpstring.data());
+		ServiceDaten->replace("directory mask",retData->data());
+//		printf("new directory mask= %s\n", tmpstring.data());
+	}
+
+	//save force create mode
+	mode=0;
+	if (ServiceWidget_Page4->fcm_oe_chkbx->isChecked()) mode=mode+1;
+	if (ServiceWidget_Page4->fcm_ow_chkbx->isChecked()) mode=mode+2;
+	if (ServiceWidget_Page4->fcm_or_chkbx->isChecked()) mode=mode+4;
+	if (ServiceWidget_Page4->fcm_ge_chkbx->isChecked()) mode=mode+10;
+	if (ServiceWidget_Page4->fcm_gw_chkbx->isChecked()) mode=mode+20;
+	if (ServiceWidget_Page4->fcm_gr_chkbx->isChecked()) mode=mode+40;
+	if (ServiceWidget_Page4->fcm_ue_chkbx->isChecked()) mode=mode+100;
+	if (ServiceWidget_Page4->fcm_uw_chkbx->isChecked()) mode=mode+200;
+	if (ServiceWidget_Page4->fcm_ur_chkbx->isChecked()) mode=mode+400;
+	tmpstring=tmpstring.setNum(mode);
+	tmpstring=tmpstring.rightJustify(4,'0');
+	if (strcmp(tmpstring.data(), ServiceDaten->find("force create mode")) != 0)
+	{
+		retData = new QString(tmpstring.data());
+		ServiceDaten->replace("force create mode",retData->data());
+//		printf("new force create mode= %s\n", tmpstring.data());
+	}
+
+	//save force directory mode
+	mode=0;
+	if (ServiceWidget_Page4->fdm_oe_chkbx->isChecked()) mode=mode+1;
+	if (ServiceWidget_Page4->fdm_ow_chkbx->isChecked()) mode=mode+2;
+	if (ServiceWidget_Page4->fdm_or_chkbx->isChecked()) mode=mode+4;
+	if (ServiceWidget_Page4->fdm_ge_chkbx->isChecked()) mode=mode+10;
+	if (ServiceWidget_Page4->fdm_gw_chkbx->isChecked()) mode=mode+20;
+	if (ServiceWidget_Page4->fdm_gr_chkbx->isChecked()) mode=mode+40;
+	if (ServiceWidget_Page4->fdm_ue_chkbx->isChecked()) mode=mode+100;
+	if (ServiceWidget_Page4->fdm_uw_chkbx->isChecked()) mode=mode+200;
+	if (ServiceWidget_Page4->fdm_ur_chkbx->isChecked()) mode=mode+400;
+	tmpstring=tmpstring.setNum(mode);
+	tmpstring=tmpstring.rightJustify(4,'0');
+	if (strcmp(tmpstring.data(), ServiceDaten->find("force directory mode")) != 0)
+	{
+		retData = new QString(tmpstring.data());
+		ServiceDaten->replace("force directory mode",retData->data());
+		printf("new force directory mode= %s\n", tmpstring.data());
+	}
+
+
+
+
+//	KDEBUG(KDEBUG_INFO,3801,"myservicewidget: exit ok/data saved");
 }
 /*
 
@@ -376,6 +516,8 @@ void myprinterwidget::saveData(QCharDict *ServiceDaten)
 void myprinterwidget::setData(QCharDict *ServiceDaten)
 {
 
+	QString tmpstring;
+
 	ServiceWidget_Page1->admin_users_lineed->setText(ServiceDaten->find("admin users"));
 
 	ServiceWidget_Page1->allow_hosts_lineed->setText(ServiceDaten->find("allow hosts"));
@@ -390,13 +532,18 @@ void myprinterwidget::setData(QCharDict *ServiceDaten)
 	else
 	ServiceWidget_Page1->browseable_chkbx->setChecked(FALSE);
 
+	if (strcmp(ServiceDaten->find("case sensitive"),"yes") == 0)
+	ServiceWidget_Page3->case_sensitive_chkbx->setChecked(TRUE);
+	else
+	ServiceWidget_Page3->case_sensitive_chkbx->setChecked(FALSE);
+
 	ServiceWidget_Page1->comment_lineed->setText(ServiceDaten->find("comment"));
 
 	if(strcmp(ServiceDaten->find("default case"),"lower") == 0) 
-		ServiceWidget_Page2->default_case_combo->setCurrentItem(0);
+		ServiceWidget_Page3->default_case_combo->setCurrentItem(0);
 		else
 		if (strcmp(ServiceDaten->find("default case"),"upper") == 0) 
-			ServiceWidget_Page2->default_case_combo->setCurrentItem(1);
+			ServiceWidget_Page3->default_case_combo->setCurrentItem(1);
 
 	if (strcmp(ServiceDaten->find("delete readonly"),"yes") == 0)
 	ServiceWidget_Page2->delete_readonly_chkbx->setChecked(TRUE);
@@ -415,11 +562,23 @@ void myprinterwidget::setData(QCharDict *ServiceDaten)
 	else
 	ServiceWidget_Page1->disable_service_chkbx->setChecked(TRUE);
 
+	ServiceWidget_Page3->dont_descend_lineed->setText(ServiceDaten->find("dont descend"));
+
+	if (strcmp(ServiceDaten->find("dos filetime resolution"),"yes") == 0)
+	ServiceWidget_Page2->dos_filetime_resolution_chkbx->setChecked(TRUE);
+	else
+	ServiceWidget_Page2->dos_filetime_resolution_chkbx->setChecked(FALSE);
+
 	if (strcmp(ServiceDaten->find("dos filetimes"),"yes") == 0)
 	ServiceWidget_Page2->dos_filetimes_chkbx->setChecked(TRUE);
 	else
 	ServiceWidget_Page2->dos_filetimes_chkbx->setChecked(FALSE);
 
+	if (strcmp(ServiceDaten->find("fake directory create times"),"yes") == 0)
+	ServiceWidget_Page2->fake_directory_create_times_chkbx->setChecked(TRUE);
+	else
+	ServiceWidget_Page2->fake_directory_create_times_chkbx->setChecked(FALSE);
+
 	if (strcmp(ServiceDaten->find("fake oplocks"),"yes") == 0)
 	ServiceWidget_Page2->fake_oplocks_chkbx->setChecked(TRUE);
 	else
@@ -442,9 +601,11 @@ void myprinterwidget::setData(QCharDict *ServiceDaten)
 	ServiceWidget_Page1->guest_only_chkbx->setChecked(FALSE);
 
 	if (strcmp(ServiceDaten->find("hide dot files"),"yes") == 0)
-	ServiceWidget_Page2->hide_dot_files_chkbx->setChecked(TRUE);
+	ServiceWidget_Page1->hide_dot_files_chkbx->setChecked(TRUE);
 	else
-	ServiceWidget_Page2->hide_dot_files_chkbx->setChecked(FALSE);
+	ServiceWidget_Page1->hide_dot_files_chkbx->setChecked(FALSE);
+
+	ServiceWidget_Page3->hide_files_lineed->setText(ServiceDaten->find("hide files"));
 
 	ServiceWidget_Page1->invalid_users_lineed->setText(ServiceDaten->find("invalid users"));
 
@@ -461,12 +622,19 @@ void myprinterwidget::setData(QCharDict *ServiceDaten)
 
 	PrinterWidget_Page1->lpq_command_lineed->setText(ServiceDaten->find("lpq command"));
 
-	if (strcmp(ServiceDaten->find("mangled names"),"yes") == 0)
-	ServiceWidget_Page2->mangled_names_chkbx->setChecked(TRUE);
+	if (strcmp(ServiceDaten->find("mangle case"),"yes") == 0)
+	ServiceWidget_Page3->mangle_case_chkbx->setChecked(TRUE);
 	else
-	ServiceWidget_Page2->mangled_names_chkbx->setChecked(FALSE);
+	ServiceWidget_Page3->mangle_case_chkbx->setChecked(FALSE);
 
-	ServiceWidget_Page2->mangling_char_lineed->setText(ServiceDaten->find("mangling char"));
+	if (strcmp(ServiceDaten->find("mangled names"),"yes") == 0)
+	ServiceWidget_Page3->mangled_names_chkbx->setChecked(TRUE);
+	else
+	ServiceWidget_Page3->mangled_names_chkbx->setChecked(FALSE);
+
+	ServiceWidget_Page3->mangling_char_lineed->setText(ServiceDaten->find("mangling char"));
+
+	ServiceWidget_Page3->mangled_map_lineed->setText(ServiceDaten->find("mangled map"));
 
 	if (strcmp(ServiceDaten->find("map archive"),"yes") == 0)
 	ServiceWidget_Page2->map_archive_chkbx->setChecked(TRUE);
@@ -508,9 +676,9 @@ void myprinterwidget::setData(QCharDict *ServiceDaten)
 	ServiceWidget_Page2->preexec_lineed->setText(ServiceDaten->find("preexec"));
 
 	if (strcmp(ServiceDaten->find("preserve case"),"yes") == 0)
-	ServiceWidget_Page2->preserve_case_chkbx->setChecked(TRUE);
+	ServiceWidget_Page3->preserve_case_chkbx->setChecked(TRUE);
 	else
-	ServiceWidget_Page2->preserve_case_chkbx->setChecked(FALSE);
+	ServiceWidget_Page3->preserve_case_chkbx->setChecked(FALSE);
 
 	PrinterWidget_Page1->print_command_lineed->setText(ServiceDaten->find("print command"));
 
@@ -562,9 +730,9 @@ void myprinterwidget::setData(QCharDict *ServiceDaten)
 	ServiceWidget_Page2->share_modes_chkbx->setChecked(FALSE);
 
 	if (strcmp(ServiceDaten->find("short preserve case"),"yes") == 0)
-	ServiceWidget_Page2->short_preserve_case_chkbx->setChecked(TRUE);
+	ServiceWidget_Page3->short_preserve_case_chkbx->setChecked(TRUE);
 	else
-	ServiceWidget_Page2->short_preserve_case_chkbx->setChecked(FALSE);
+	ServiceWidget_Page3->short_preserve_case_chkbx->setChecked(FALSE);
 
 	if (strcmp(ServiceDaten->find("strict locking"),"yes") == 0)
 	ServiceWidget_Page2->strict_locking_chkbx->setChecked(TRUE);
@@ -596,6 +764,231 @@ void myprinterwidget::setData(QCharDict *ServiceDaten)
 
 	ServiceWidget_Page1->write_list_lineed->setText(ServiceDaten->find("write list"));
 
+//	ServiceWidget_Page4
+	
+// 	printf("cm %d\n",atoi(ServiceDaten->find("create mask")));
+	tmpstring = ServiceDaten->find("create mask");
+	tmpstring = tmpstring.mid(1,1);
+	
+	if ((tmpstring.toInt() & 4) == 4)
+	ServiceWidget_Page4->cm_ur_chkbx->setChecked(TRUE);
+	else
+	ServiceWidget_Page4->cm_ur_chkbx->setChecked(FALSE);
+  	
+	if ((tmpstring.toInt() & 2) == 2)
+	ServiceWidget_Page4->cm_uw_chkbx->setChecked(TRUE);
+	else
+	ServiceWidget_Page4->cm_uw_chkbx->setChecked(FALSE);
+
+	if ((tmpstring.toInt() & 1) == 1)
+	ServiceWidget_Page4->cm_ue_chkbx->setChecked(TRUE);
+	else
+	ServiceWidget_Page4->cm_ue_chkbx->setChecked(FALSE);
+
+	tmpstring = ServiceDaten->find("create mask");
+	tmpstring = tmpstring.mid(2,1);
+
+	if ((tmpstring.toInt() & 4) == 4)
+	ServiceWidget_Page4->cm_gr_chkbx->setChecked(TRUE);
+	else
+	ServiceWidget_Page4->cm_gr_chkbx->setChecked(FALSE);
+  		
+	if ((tmpstring.toInt() & 2) == 2)
+	ServiceWidget_Page4->cm_gw_chkbx->setChecked(TRUE);
+	else
+	ServiceWidget_Page4->cm_gw_chkbx->setChecked(FALSE);
+
+	if ((tmpstring.toInt() & 1) == 1)
+	ServiceWidget_Page4->cm_ge_chkbx->setChecked(TRUE);
+	else
+	ServiceWidget_Page4->cm_ge_chkbx->setChecked(FALSE);
+
+  	tmpstring = ServiceDaten->find("create mask");
+	tmpstring = tmpstring.mid(3,1);
+	
+	if ((tmpstring.toInt() & 4) == 4)
+	ServiceWidget_Page4->cm_or_chkbx->setChecked(TRUE);
+	else
+	ServiceWidget_Page4->cm_or_chkbx->setChecked(FALSE);
+  		
+	if ((tmpstring.toInt() & 2) == 2)
+	ServiceWidget_Page4->cm_ow_chkbx->setChecked(TRUE);
+	else
+	ServiceWidget_Page4->cm_ow_chkbx->setChecked(FALSE);
+
+	if ((tmpstring.toInt() & 1) == 1)
+	ServiceWidget_Page4->cm_oe_chkbx->setChecked(TRUE);
+	else
+	ServiceWidget_Page4->cm_oe_chkbx->setChecked(FALSE);
+	
+
+
+	tmpstring = ServiceDaten->find("directory mask");
+	tmpstring = tmpstring.mid(1,1);
+	
+	if ((tmpstring.toInt() & 4) == 4)
+	ServiceWidget_Page4->dm_ur_chkbx->setChecked(TRUE);
+	else
+	ServiceWidget_Page4->dm_ur_chkbx->setChecked(FALSE);
+  	
+	if ((tmpstring.toInt() & 2) == 2)
+	ServiceWidget_Page4->dm_uw_chkbx->setChecked(TRUE);
+	else
+	ServiceWidget_Page4->dm_uw_chkbx->setChecked(FALSE);
+
+	if ((tmpstring.toInt() & 1) == 1)
+	ServiceWidget_Page4->dm_ue_chkbx->setChecked(TRUE);
+	else
+	ServiceWidget_Page4->dm_ue_chkbx->setChecked(FALSE);
+
+	tmpstring = ServiceDaten->find("directory mask");
+	tmpstring = tmpstring.mid(2,1);
+
+	if ((tmpstring.toInt() & 4) == 4)
+	ServiceWidget_Page4->dm_gr_chkbx->setChecked(TRUE);
+	else
+	ServiceWidget_Page4->dm_gr_chkbx->setChecked(FALSE);
+  		
+	if ((tmpstring.toInt() & 2) == 2)
+	ServiceWidget_Page4->dm_gw_chkbx->setChecked(TRUE);
+	else
+	ServiceWidget_Page4->dm_gw_chkbx->setChecked(FALSE);
+
+	if ((tmpstring.toInt() & 1) == 1)
+	ServiceWidget_Page4->dm_ge_chkbx->setChecked(TRUE);
+	else
+	ServiceWidget_Page4->dm_ge_chkbx->setChecked(FALSE);
+
+  	tmpstring = ServiceDaten->find("directory mask");
+	tmpstring = tmpstring.mid(3,1);
+	
+	if ((tmpstring.toInt() & 4) == 4)
+	ServiceWidget_Page4->dm_or_chkbx->setChecked(TRUE);
+	else
+	ServiceWidget_Page4->dm_or_chkbx->setChecked(FALSE);
+  		
+	if ((tmpstring.toInt() & 2) == 2)
+	ServiceWidget_Page4->dm_ow_chkbx->setChecked(TRUE);
+	else
+	ServiceWidget_Page4->dm_ow_chkbx->setChecked(FALSE);
+
+	if ((tmpstring.toInt() & 1) == 1)
+	ServiceWidget_Page4->dm_oe_chkbx->setChecked(TRUE);
+	else
+	ServiceWidget_Page4->dm_oe_chkbx->setChecked(FALSE);
+	
+
+	tmpstring = ServiceDaten->find("force create mode");
+	tmpstring = tmpstring.mid(1,1);
+	
+	if ((tmpstring.toInt() & 4) == 4)
+	ServiceWidget_Page4->fcm_ur_chkbx->setChecked(TRUE);
+	else
+	ServiceWidget_Page4->fcm_ur_chkbx->setChecked(FALSE);
+  	
+	if ((tmpstring.toInt() & 2) == 2)
+	ServiceWidget_Page4->fcm_uw_chkbx->setChecked(TRUE);
+	else
+	ServiceWidget_Page4->fcm_uw_chkbx->setChecked(FALSE);
+
+	if ((tmpstring.toInt() & 1) == 1)
+	ServiceWidget_Page4->fcm_ue_chkbx->setChecked(TRUE);
+	else
+	ServiceWidget_Page4->fcm_ue_chkbx->setChecked(FALSE);
+
+	tmpstring = ServiceDaten->find("force create mode");
+	tmpstring = tmpstring.mid(2,1);
+
+	if ((tmpstring.toInt() & 4) == 4)
+	ServiceWidget_Page4->fcm_gr_chkbx->setChecked(TRUE);
+	else
+	ServiceWidget_Page4->fcm_gr_chkbx->setChecked(FALSE);
+  		
+	if ((tmpstring.toInt() & 2) == 2)
+	ServiceWidget_Page4->fcm_gw_chkbx->setChecked(TRUE);
+	else
+	ServiceWidget_Page4->fcm_gw_chkbx->setChecked(FALSE);
+
+	if ((tmpstring.toInt() & 1) == 1)
+	ServiceWidget_Page4->fcm_ge_chkbx->setChecked(TRUE);
+	else
+	ServiceWidget_Page4->fcm_ge_chkbx->setChecked(FALSE);
+
+  	tmpstring = ServiceDaten->find("force create mode");
+	tmpstring = tmpstring.mid(3,1);
+	
+	if ((tmpstring.toInt() & 4) == 4)
+	ServiceWidget_Page4->fcm_or_chkbx->setChecked(TRUE);
+	else
+	ServiceWidget_Page4->fcm_or_chkbx->setChecked(FALSE);
+  		
+	if ((tmpstring.toInt() & 2) == 2)
+	ServiceWidget_Page4->fcm_ow_chkbx->setChecked(TRUE);
+	else
+	ServiceWidget_Page4->fcm_ow_chkbx->setChecked(FALSE);
+
+	if ((tmpstring.toInt() & 1) == 1)
+	ServiceWidget_Page4->fcm_oe_chkbx->setChecked(TRUE);
+	else
+	ServiceWidget_Page4->fcm_oe_chkbx->setChecked(FALSE);
+	
+
+
+	tmpstring = ServiceDaten->find("force directory mode");
+	tmpstring = tmpstring.mid(1,1);
+	
+	if ((tmpstring.toInt() & 4) == 4)
+	ServiceWidget_Page4->fdm_ur_chkbx->setChecked(TRUE);
+	else
+	ServiceWidget_Page4->fdm_ur_chkbx->setChecked(FALSE);
+  	
+	if ((tmpstring.toInt() & 2) == 2)
+	ServiceWidget_Page4->fdm_uw_chkbx->setChecked(TRUE);
+	else
+	ServiceWidget_Page4->fdm_uw_chkbx->setChecked(FALSE);
+
+	if ((tmpstring.toInt() & 1) == 1)
+	ServiceWidget_Page4->fdm_ue_chkbx->setChecked(TRUE);
+	else
+	ServiceWidget_Page4->fdm_ue_chkbx->setChecked(FALSE);
+
+	tmpstring = ServiceDaten->find("force directory mode");
+	tmpstring = tmpstring.mid(2,1);
+
+	if ((tmpstring.toInt() & 4) == 4)
+	ServiceWidget_Page4->fdm_gr_chkbx->setChecked(TRUE);
+	else
+	ServiceWidget_Page4->fdm_gr_chkbx->setChecked(FALSE);
+  		
+	if ((tmpstring.toInt() & 2) == 2)
+	ServiceWidget_Page4->fdm_gw_chkbx->setChecked(TRUE);
+	else
+	ServiceWidget_Page4->fdm_gw_chkbx->setChecked(FALSE);
+
+	if ((tmpstring.toInt() & 1) == 1)
+	ServiceWidget_Page4->fdm_ge_chkbx->setChecked(TRUE);
+	else
+	ServiceWidget_Page4->fdm_ge_chkbx->setChecked(FALSE);
+
+  	tmpstring = ServiceDaten->find("force directory mode");
+	tmpstring = tmpstring.mid(3,1);
+	
+	if ((tmpstring.toInt() & 4) == 4)
+	ServiceWidget_Page4->fdm_or_chkbx->setChecked(TRUE);
+	else
+	ServiceWidget_Page4->fdm_or_chkbx->setChecked(FALSE);
+  		
+	if ((tmpstring.toInt() & 2) == 2)
+	ServiceWidget_Page4->fdm_ow_chkbx->setChecked(TRUE);
+	else
+	ServiceWidget_Page4->fdm_ow_chkbx->setChecked(FALSE);
+
+	if ((tmpstring.toInt() & 1) == 1)
+	ServiceWidget_Page4->fdm_oe_chkbx->setChecked(TRUE);
+	else
+	ServiceWidget_Page4->fdm_oe_chkbx->setChecked(FALSE);
+
+
 }
 /*
 
