@@ -17,8 +17,9 @@
 
 #include "myservicewidget_page1.h"
 #include "myservicewidget_page2.h"
+#include "myservicewidget_page3.h"
+#include "myservicewidget_page4.h"
 #include "myprinterwidget_page1.h"
-//#include "myglobalwidget_page4.h"
 
 class myprinterwidget : public QTabDialog
 {
@@ -36,8 +37,9 @@ public:
 private:
 	myservicewidget_page1 *ServiceWidget_Page1;
 	myservicewidget_page2 *ServiceWidget_Page2;
+	myservicewidget_page3 *ServiceWidget_Page3;
+	myservicewidget_page4 *ServiceWidget_Page4;
 	myprinterwidget_page1 *PrinterWidget_Page1;
-//	myglobalwidget_page4 *GlobalWidget_Page4;
 	QTabDialog *TabDialog;
 	QString *retData;
 };
