@@ -17,8 +17,8 @@
 
 #include "myservicewidget_page1.h"
 #include "myservicewidget_page2.h"
-//#include "myglobalwidget_page3.h"
-//#include "myglobalwidget_page4.h"
+#include "myservicewidget_page3.h"
+#include "myservicewidget_page4.h"
 
 class myservicewidget : public QTabDialog
 {
@@ -36,8 +36,9 @@ public:
 private:
 	myservicewidget_page1 *ServiceWidget_Page1;
 	myservicewidget_page2 *ServiceWidget_Page2;
-//	myglobalwidget_page3 *GlobalWidget_Page3;
-//	myglobalwidget_page4 *GlobalWidget_Page4;
+	myservicewidget_page3 *ServiceWidget_Page3;
+	myservicewidget_page4 *ServiceWidget_Page4;
+
 	QTabDialog *TabDialog;
 	QString *retData;
 };
